NAME

Google::Auth::EnvironmentVars - Environment variables used by Google::Auth

VERSION

Version 0.07

SYNOPSIS

Canonical package for reading environment variables used with Google::Auth

METHODS

PROJECT

This env variable is used by Google::Auth to explicitly set a project ID. This environment variable is also used by the Google Cloud Perl Library.

LEGACY_PROJECT

This environment variable is used instead of the current one in some situations (such as Google App Engine).

CREDENTIALS

Environment variable defining the location of Google application default credentials

CLOUD_SDK_CONFIG_DIR

The environment variable name which can replace ~/.config if set

GCE_METADATA_ROOT

This and the following variable allow for customization of the addresses used when contacting the GCE metadata service.

GCE_METADATA_IP

AUTHOR

C.J. Collier, <cjac at google.com>

BUGS AND SUPPORT

Please report any bugs or feature requests to the GitHub issue tracker at https://github.com/GoogleCloudPlatform/google-auth-library-perl/issues or via RT at https://rt.cpan.org/Dist/Display.html?Name=Google-Auth.

You can also look for information at:

ACKNOWLEDGEMENTS

LICENSE AND COPYRIGHT

Copyright 2020 Google LLC and contributors

This program is released under the following license: Apache 2.0